@@ -12,8 +12,6 @@ from youamp.library import Library, check_db
 from youamp.player import Player
 from youamp.config import Config
 
-#from youamp.mscrobbler import MaemoScrobbler
-
 if IS_MAEMO:
     import osso
     
@@ -27,7 +25,6 @@ class Controller:
         self._player = Player(self._config)
         self._library = Library()
         self._window = Window(self._player, self._config, self._library)
-        #self._scrobbler = MaemoScrobbler()
         
         # programm
         program = hildon.Program()
@@ -53,11 +50,11 @@ class Controller:
         view.set_submenu(view_sub)
         
         search = gtk.RadioMenuItem(None, _("Search"))
-        search.connect("activate", lambda caller: self._window._view.search_mode())
+        search.connect("activate", lambda caller: self._window.view.search_mode())
         view_sub.append(search)
         
         browse = gtk.RadioMenuItem(search, _("Browse"))
-        browse.connect("activate", lambda caller: self._window._view.browse_mode())
+        browse.connect("activate", lambda caller: self._window.view.browse_mode())
         view_sub.append(browse)
     
         # order submenu
@@ -131,13 +128,11 @@ class Controller:
     def _set_list_order(self, order):
         self._config["order-by"] = order
         self._config["shuffle"] = False
-        
-        if self._config["is-browser"]:
-            playlist = self._library.get_tracks(self._config)
-        else:
-            playlist = self._library.search(self._config)
+        self._config["pos"] = 0
+
+        playlist = self._library.get_tracks(self._config)
             
-        self._window._view._set_playlist(playlist)
+        self._player.playlist.update(playlist)
 
     def _on_song_played(self, caller, song):
         self._library.increment_played(song.uri)
@@ -163,8 +158,10 @@ class Controller:
         
         if key == "Right":
             self._window._controls.on_next()
+            return True # event handled
         elif key == "Left":
             self._window._controls.on_prev()
+            return True # event handled
         if key == "F7":
             self._on_vol_up()
         elif key == "F8":
