@@ -51,23 +51,7 @@ class Library(GObject, Thread):
         return albums
     
     def get_tracks(self, config):        
-        artist = config["search-artist"]
-        album = config["search-album"]
-        
-        where_clause = "" if (artist == "" and album == "") else "WHERE "
-        variables = ()
-        
-        # build query
-        if artist != "":
-            where_clause += "artist = ?"
-            variables += (artist,)
-        
-        if artist != "" and album != "":
-            where_clause += " AND "
-        
-        if album != "":
-            where_clause += "album = ?"
-            variables += (album,)            
+        where_clause, variables = self._build_where_clause(config)
 
         playlist = self._cursor.execute("""SELECT uri, title, artist, album
                                           FROM songs 
@@ -77,24 +61,37 @@ class Library(GObject, Thread):
 
         return map(lambda e: Song(e), playlist)
     
-    def search(self, config):
+    def _build_where_clause(self, config):
         where_clause = ""
         variables = ()
         
-        name = config["search-str"]
+        if config["is-browser"]:
+            artist = config["search-artist"]
+            album = config["search-album"]
+            
+            if (artist != "" or album != ""):
+                where_clause = "WHERE "
+            
+            # build query
+            if artist != "":
+                where_clause += "artist = ?"
+                variables += (artist,)
+            
+            if artist != "" and album != "":
+                where_clause += " AND "
+            
+            if album != "":
+                where_clause += "album = ?"
+                variables += (album,) 
+        else:
+            name = config["search-str"]
+            
+            if name != "":
+                where_clause += "WHERE artist || album || title LIKE ?"
+                name = "%"+"%".join(name.split())+"%"  # insert wildcard on spaces
+                variables = (name,)
         
-        if name != "":
-            where_clause += "WHERE artist || album || title LIKE ?"
-            name = "%"+"%".join(name.split())+"%"  # insert wildcard on spaces
-            variables += (name,)
-        
-        playlist = self._cursor.execute("""SELECT uri, title, artist, album
-                                          FROM songs 
-                                          %s
-                                          ORDER BY %s""" % (where_clause, order[config["order-by"]]), \
-                                          variables).fetchall()
-
-        return map(lambda e: Song(e), playlist)
+        return (where_clause, variables)
 
     def increment_played(self, song_uri):
         self._cursor.execute("""UPDATE songs SET playcount = playcount + 1 WHERE uri = ?""", (song_uri,))
