@@ -108,8 +108,6 @@ class Player(GObject):
         self.playing = True
         self.load_track()
         self._player.set_state(gst.STATE_PLAYING)
-        
-        #self._scrobbler.send_start(self._current)
 
     def _on_error(self, bus, message):
         print "Error: %s" % message.parse_error()[0]
@@ -119,7 +117,7 @@ class Player(GObject):
 
     def _update_tags(self, path):        
         for k, v in mutagen.File(path).items():
-            k = k.replace("_", "-") # use gstreamer formatting
+            k = k.replace("_", "-") # use gstreamer formatting "-" istead of "_"
             v = str(", ".join(v))   # flatten value
             if k [0:10] == "replaygain":
                 v = v[0:-3]
