@@ -53,7 +53,7 @@ class SearchView(gtk.VBox):
         
         # Navi Search Entry
         self._search_entry = gtk.Entry()
-        self._search_entry.connect("activate", self._search)
+        self._search_entry.connect("activate", self._on_search_click)
         self._search_entry.set_text(self._config["search-str"])
         navi.pack_start(self._search_entry, expand=True)
         
@@ -97,7 +97,7 @@ class SearchView(gtk.VBox):
         
         self._restore_playlist()
             
-        self._player.connect("song-changed", self._on_song_changed)
+        self._config.notify_add("pos", self._on_pos_changed)
         
         # browser callbacks
         self._config.notify_add("search-artist", self._on_search_artist)
@@ -109,15 +109,13 @@ class SearchView(gtk.VBox):
         
     def _restore_playlist(self):
         if self._config["is-browser"]:
-            playlist = self._library.get_tracks(self._config)
-            
             if self._config["search-artist"] == "":
                 self._artist.get_child().set_text(_("All Artists"))
             
             if self._config["search-album"] == "":
                 self._album.get_child().set_text(_("All Albums"))
-        else:
-            playlist = self._library.search(self._config)
+        
+        playlist = self._library.get_tracks(self._config)
 
         self._player.playlist.update(playlist)
         
@@ -133,21 +131,19 @@ class SearchView(gtk.VBox):
         
         self._show_playlist()
  
-    def _search(self, caller):
+    def _on_search_click(self, caller):
         self._config["search-str"] = caller.get_text()
         self._config["shuffle"] = self.shuffle.get_active()
-                
-        playlist = self._library.search(self._config)
+        self._config["is-browser"] = False
+        
+        playlist = self._library.get_tracks(self._config)
         
         self._set_playlist(playlist)
         
         self._config.notify("search-str")
-        
-        self._config["is-browser"] = False
-    
+
     def _set_playlist(self, data):
         self._config["pos"] = 0
-        self._playlist.set_cursor(0)
 
         self._player.playlist.update(data)
         
@@ -232,11 +228,11 @@ class SearchView(gtk.VBox):
         self._browser.show_artists()
         self._browser._state = NOTHING_SELECTED
 
-    def _on_song_changed(self, caller, newsong):
-        self._playlist.set_cursor(self._config["pos"])
-
     def _on_row_activated(self, caller, path, column):
         self._player.goto_pos(path[0])
+    
+    def _on_pos_changed(self, *args):
+        self._playlist.set_cursor(self._config["pos"])
 
 class PlaylistView(gtk.TreeView):
     def __init__(self, model, config):        
